@@ -12,3 +12,11 @@ class UnknownPlatformError(GetChromeDriverError):
 
 class UnknownReleaseError(GetChromeDriverError):
     pass
+
+
+class DownloadError(GetChromeDriverError):
+    pass
+
+
+class VersionError(GetChromeDriverError):
+    pass
