@@ -4,11 +4,15 @@ class Platforms:
         self.win = self.__win()
         self.linux = self.__linux()
         self.mac = self.__mac()
+
         self.list = self.__list()
 
-        self.win_arch = self.__win_arch()
-        self.linux_arch = self.__linux_arch()
-        self.mac_arch = self.__mac_arch()
+        self.win_32 = self.__win_32()
+        self.win_64 = self.__win_64()
+        self.linux_32 = self.__linux_32()
+        self.linux_64 = self.__linux_64()
+        self.mac_32 = self.__mac_32()
+        self.mac_64 = self.__mac_64()
 
     def __win(self):
         return 'win'
@@ -19,13 +23,22 @@ class Platforms:
     def __mac(self):
         return 'mac'
 
-    def __win_arch(self):
+    def __win_32(self):
         return 'win32'
 
-    def __linux_arch(self):
+    def __win_64(self):
+        return 'win64'
+
+    def __linux_32(self):
+        return 'linux32'
+
+    def __linux_64(self):
         return 'linux64'
 
-    def __mac_arch(self):
+    def __mac_32(self):
+        return 'mac32'
+
+    def __mac_64(self):
         return 'mac64'
 
     def __list(self):
