@@ -2,12 +2,14 @@ import pytest
 import os
 import shutil
 import subprocess
+import platform as pl
 from os import path
 
 from bs4 import BeautifulSoup
 import requests
 from decouple import config
 
+from get_chrome_driver import GetChromeDriver
 from .. import constants
 from .. import __version__
 from ..platforms import Platforms
@@ -19,13 +21,21 @@ platforms = Platforms()
 stable_release = config('STABLE_RELEASE')
 random_release = config('RANDOM_RELEASE')
 
-stable_release_win_url = 'https://chromedriver.storage.googleapis.com/' + stable_release + '/chromedriver_win32.zip'
-stable_release_linux_url = 'https://chromedriver.storage.googleapis.com/' + stable_release + '/chromedriver_linux64.zip'
-stable_release_mac_url = 'https://chromedriver.storage.googleapis.com/' + stable_release + '/chromedriver_mac64.zip'
-
-random_release_win_url = 'https://chromedriver.storage.googleapis.com/' + random_release + '/chromedriver_win32.zip'
-random_release_linux_url = 'https://chromedriver.storage.googleapis.com/' + random_release + '/chromedriver_linux64.zip'
-random_release_mac_url = 'https://chromedriver.storage.googleapis.com/' + random_release + '/chromedriver_mac64.zip'
+if pl.system() == 'Windows':
+    file_name_zipped = 'chromedriver_win32.zip'
+    file_name = 'chromedriver.exe'
+    stable_release_url = 'https://chromedriver.storage.googleapis.com/' + stable_release + '/' + file_name_zipped
+    random_release_url = 'https://chromedriver.storage.googleapis.com/' + random_release + '/' + file_name_zipped
+elif pl.system() == 'Linux':
+    file_name_zipped = 'chromedriver_linux64.zip'
+    file_name = 'chromedriver'
+    stable_release_url = 'https://chromedriver.storage.googleapis.com/' + stable_release + '/' + file_name_zipped
+    random_release_url = 'https://chromedriver.storage.googleapis.com/' + random_release + '/' + file_name_zipped
+elif pl.system() == 'Darwin':
+    file_name_zipped = 'chromedriver_mac64.zip'
+    file_name = 'chromedriver'
+    stable_release_url = 'https://chromedriver.storage.googleapis.com/' + stable_release + '/' + file_name_zipped
+    random_release_url = 'https://chromedriver.storage.googleapis.com/' + random_release + '/' + file_name_zipped
 
 # Change to the current test directory
 os.chdir(os.path.dirname(__file__))
@@ -80,166 +90,90 @@ class TestApp:
     ######################
     # RANDOM RELEASE URL #
     ######################
-    def test_random_win_release_url(self):
-        url = random_release_win_url
-        out = subprocess.run(args=[name, '--release-url', 'win', random_release],
+    def test_random_release_url(self):
+        url = random_release_url
+        out = subprocess.run(args=[name, '--release-url', random_release],
                              universal_newlines=True,
                              stdout=subprocess.PIPE)
         actual = out.stdout.split()[0]
         assert url, str(actual)
 
-    def test_random_linux_release_url(self):
-        url = random_release_linux_url
-        out = subprocess.run(args=[name, '--release-url', 'linux', random_release],
-                             universal_newlines=True,
-                             stdout=subprocess.PIPE)
-        actual = out.stdout.split()[0]
-        assert url == str(actual)
-
-    def test_random_mac_release_url(self):
-        url = random_release_mac_url
-        out = subprocess.run(args=[name, '--release-url', 'mac', random_release],
-                             universal_newlines=True,
-                             stdout=subprocess.PIPE)
-        actual = out.stdout.split()[0]
-        assert url == str(actual)
-
     ######################
     # STABLE RELEASE URL #
     ######################
-    def test_stable_win_release_url(self):
-        url = stable_release_win_url
-        out = subprocess.run(args=[name, '--stable-url', 'win'],
+    def test_stable_release_url(self):
+        url = stable_release_url
+        out = subprocess.run(args=[name, '--stable-url'],
                              universal_newlines=True,
                              stdout=subprocess.PIPE)
         actual = out.stdout.split()[0]
         assert url == str(actual)
 
-    def test_stable_linux_release_url(self):
-        url = stable_release_linux_url
-        out = subprocess.run(args=[name, '--stable-url', 'linux'],
-                             universal_newlines=True,
-                             stdout=subprocess.PIPE)
-        actual = out.stdout.split()[0]
-        assert url == str(actual)
+    ##############################
+    # AUTO DOWNLOAD - NO EXTRACT #
+    ##############################
+    def test_auto_download_no_extract(self):
+        get_driver = GetChromeDriver()
+        release = get_driver.matching_version()
+        subprocess.run(args=[name, '--auto-download'], stdout=subprocess.PIPE)
+        file_path = get_driver._create_output_path_str(release) + '/' + file_name_zipped
+        result = path.exists(file_path)
+        assert result
 
-    def test_stable_mac_release_url(self):
-        url = stable_release_mac_url
-        out = subprocess.run(args=[name, '--stable-url', 'mac'],
-                             universal_newlines=True,
-                             stdout=subprocess.PIPE)
-        actual = out.stdout.split()[0]
-        assert url == str(actual)
+    ###########################
+    # AUTO DOWNLOAD - EXTRACT #
+    ###########################
+    def test_auto_download_extract(self):
+        get_driver = GetChromeDriver()
+        release = get_driver.matching_version()
+        subprocess.run(args=[name, '--auto-download', '--extract'], stdout=subprocess.PIPE)
+        file_path_extracted = get_driver._create_output_path_str(release) + '/' + file_name
+        result = path.exists(file_path_extracted)
+        assert result
 
     ########################################
     # DOWNLOAD STABLE RELEASE - NO EXTRACT #
     ########################################
-    def test_download_stable_win_release_no_extract(self):
+    def test_download_stable_release_no_extract(self):
+        get_driver = GetChromeDriver()
         release = stable_release
-        subprocess.run(args=[name, '--download-stable', 'win'], stdout=subprocess.PIPE)
-        file_path = (constants.DIR_DOWNLOADS + '/' + release + '/'
-                     + platforms.win_arch + '/' + constants.FILE_NAME_CHROMEDRIVER_WIN_ZIP)
-        result = path.exists(file_path)
-        assert result
-
-    def test_download_stable_linux_release_no_extract(self):
-        release = stable_release
-        subprocess.run(args=[name, '--download-stable', 'linux'], stdout=subprocess.PIPE)
-        file_path = (constants.DIR_DOWNLOADS + '/' + release + '/'
-                     + platforms.linux_arch + '/' + constants.FILE_NAME_CHROMEDRIVER_LINUX_ZIP)
-        result = path.exists(file_path)
-        assert result
-
-    def test_download_stable_mac_release_no_extract(self):
-        release = stable_release
-        subprocess.run(args=[name, '--download-stable', 'mac'], stdout=subprocess.PIPE)
-        file_path = (constants.DIR_DOWNLOADS + '/' + release + '/'
-                     + platforms.mac_arch + '/' + constants.FILE_NAME_CHROMEDRIVER_MAC_ZIP)
+        subprocess.run(args=[name, '--download-stable'], stdout=subprocess.PIPE)
+        file_path = get_driver._create_output_path_str(release) + '/' + file_name_zipped
         result = path.exists(file_path)
         assert result
 
     #######################################
     # DOWNLOAD STABLE RELEASE - EXTRACTED #
     #######################################
-    def test_download_stable_win_release_extract(self):
+    def test_download_stable_release_extract(self):
+        get_driver = GetChromeDriver()
         release = stable_release
-        subprocess.run(args=[name, '--download-stable', 'win', '--extract'], stdout=subprocess.PIPE)
-        file_path_extracted = (constants.DIR_DOWNLOADS + '/' + release + '/'
-                               + platforms.win_arch + '/' + constants.FILE_NAME_CHROMEDRIVER_EXE)
-        result = path.exists(file_path_extracted)
-        assert result
-
-    def test_download_stable_linux_release_extract(self):
-        release = stable_release
-        subprocess.run(args=[name, '--download-stable', 'linux', '--extract'], stdout=subprocess.PIPE)
-        file_path_extracted = (constants.DIR_DOWNLOADS + '/' + release + '/'
-                               + platforms.win_arch + '/' + constants.FILE_NAME_CHROMEDRIVER_EXE)
-        result = path.exists(file_path_extracted)
-        assert result
-
-    def test_download_stable_mac_release_extract(self):
-        release = stable_release
-        subprocess.run(args=[name, '--download-stable', 'mac', '--extract'], stdout=subprocess.PIPE)
-        file_path_extracted = (constants.DIR_DOWNLOADS + '/' + release + '/'
-                               + platforms.win_arch + '/' + constants.FILE_NAME_CHROMEDRIVER_EXE)
+        subprocess.run(args=[name, '--download-stable', '--extract'], stdout=subprocess.PIPE)
+        file_path_extracted = get_driver._create_output_path_str(release) + '/' + file_name
         result = path.exists(file_path_extracted)
         assert result
 
     ########################################
     # DOWNLOAD RANDOM RELEASE - NO EXTRACT #
     ########################################
-    def test_download_random_win_release_no_extract(self):
+    def test_download_random_release_no_extract(self):
+        get_driver = GetChromeDriver()
         release = random_release
-        subprocess.run(args=[name, '--download-release', 'win', release], stdout=subprocess.PIPE)
-        file_path = (constants.DIR_DOWNLOADS + '/' + release + '/'
-                     + platforms.win_arch + '/' + constants.FILE_NAME_CHROMEDRIVER_WIN_ZIP)
-        result = path.exists(file_path)
-        assert result
-
-    def test_download_random_linux_release_no_extract(self):
-        release = random_release
-        subprocess.run(args=[name, '--download-release', 'linux', release], stdout=subprocess.PIPE)
-        file_path = (constants.DIR_DOWNLOADS + '/' + release + '/'
-                     + platforms.linux_arch + '/' + constants.FILE_NAME_CHROMEDRIVER_LINUX_ZIP)
-        result = path.exists(file_path)
-        assert result
-
-    def test_download_random_mac_release_no_extract(self):
-        release = random_release
-        subprocess.run(args=[name, '--download-release', 'mac', release], stdout=subprocess.PIPE)
-        file_path = (constants.DIR_DOWNLOADS + '/' + release + '/'
-                     + platforms.mac_arch + '/' + constants.FILE_NAME_CHROMEDRIVER_MAC_ZIP)
+        subprocess.run(args=[name, '--download-release', release], stdout=subprocess.PIPE)
+        file_path = get_driver._create_output_path_str(release) + '/' + file_name_zipped
         result = path.exists(file_path)
         assert result
 
     #######################################
     # DOWNLOAD RANDOM RELEASE - EXTRACTED #
     #######################################
-    def test_download_random_win_release_extract(self):
+    def test_download_random_release_extract(self):
+        get_driver = GetChromeDriver()
         release = random_release
-        subprocess.run(args=[name, '--download-release', 'win', release, '--extract'],
+        subprocess.run(args=[name, '--download-release', release, '--extract'],
                        stdout=subprocess.PIPE)
-        file_path_extract = (constants.DIR_DOWNLOADS + '/' + release + '/'
-                             + platforms.win_arch + '/' + constants.FILE_NAME_CHROMEDRIVER_EXE)
-        result = path.exists(file_path_extract)
-        assert result
-
-    def test_download_random_linux_release_extract(self):
-        release = random_release
-        subprocess.run(args=[name, '--download-release', 'linux', release, '--extract'],
-                       stdout=subprocess.PIPE)
-        file_path_extract = (constants.DIR_DOWNLOADS + '/' + release + '/'
-                             + platforms.linux_arch + '/' + constants.FILE_NAME_CHROMEDRIVER)
-        result = path.exists(file_path_extract)
-        assert result
-
-    def test_download_random_mac_release_extract(self):
-        release = random_release
-        subprocess.run(args=[name, '--download-release', 'mac', release, '--extract'],
-                       stdout=subprocess.PIPE)
-        file_path_extract = (constants.DIR_DOWNLOADS + '/' + release + '/'
-                             + platforms.mac_arch + '/' + constants.FILE_NAME_CHROMEDRIVER)
-        result = path.exists(file_path_extract)
+        file_path_extracted = get_driver._create_output_path_str(release) + '/' + file_name
+        result = path.exists(file_path_extracted)
         assert result
 
     ###########
@@ -255,10 +189,10 @@ class TestApp:
     ###########
     # CLEANUP #
     ###########
-    @pytest.fixture(scope='session', autouse=True)
+    @pytest.fixture(scope='function', autouse=True)
     def cleanup(self):
         yield
         try:
-            shutil.rmtree(constants.DIR_DOWNLOADS)
+            shutil.rmtree(constants.CHROMEDRIVER)
         except FileNotFoundError:
             pass
